﻿using System.Windows;
using System.Windows.Browser;
using BMv7.SilverlightStreetsideModule.Views;
using Microsoft.Maps.MapControl;

namespace BMv7.SilverlightStreetsideModule.ViewModels
{
    [ScriptableType]
    public class StreetsideMapViewModel
    {
        private StreetsideMapView _mapView;
        private string _hideMapMethod = string.Empty;

        public StreetsideMapViewModel(StreetsideMapView mapView, string bingMapsKey)
        {
            _mapView = mapView;

            _mapView.Map.CredentialsProvider = new ApplicationIdCredentialsProvider(bingMapsKey);
            _mapView.MiniMap.CredentialsProvider = new ApplicationIdCredentialsProvider(bingMapsKey);

            _mapView.Map.Mode = new Microsoft.Maps.MapControl.ExtendedModes.StreetsideMode();

            _mapView.Map.ViewChangeEnd += (s, a) =>
            {
                if (_mapView.MiniMap.Center != _mapView.Map.Center)
                {
                    _mapView.MiniMap.Center = _mapView.Map.Center;
                }
            };

            _mapView.MiniMap.ViewChangeEnd += (s, a) =>
            {
                if (_mapView.MiniMap.Center != _mapView.Map.Center)
                {
                    _mapView.Map.Center = _mapView.MiniMap.Center;
                }
            };

            _mapView.FadeOutMap.Completed += (s, a) =>
            {
                if (!string.IsNullOrWhiteSpace(_hideMapMethod))
                {
                    //Hide the Silverlight Control so it doesn't block mouse events on the AJAX Map
                    HtmlPage.Window.Invoke(_hideMapMethod);
                }
            };

            _mapView.ExitBtn.Click += (s, a) =>
            {
                if (Application.Current.Host.Content.IsFullScreen)
                {
                    Application.Current.Host.Content.IsFullScreen = false;
                }

                _mapView.FadeOutMap.Begin();
            };

            _mapView.FullScreenBtn.Click += (s, a) =>
            {
                Application.Current.Host.Content.IsFullScreen = !Application.Current.Host.Content.IsFullScreen;
            };
        }        

        [ScriptableMember]
        public void SetHideMapMethod(string method)
        {
            _hideMapMethod = method;
        }

        [ScriptableMember]
        public void SetMapView(double lat, double lon)
        {
            _mapView.Map.AnimationLevel = AnimationLevel.None;
            _mapView.Map.Mode.Center = new Location(lat, lon);
            _mapView.Map.ZoomLevel = 20;
            _mapView.Map.Mode = new Microsoft.Maps.MapControl.ExtendedModes.StreetsideMode();
            _mapView.FadeInMap.Begin();
        }
    }
}
